@@ -18,14 +18,23 @@
  */
 
 #include <QApplication>
+#include <QTranslator>
+#include <QLocale>
 
 #include "vmainwindow.h"
 
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    VMainWindow win("/opt/viito/data/images.xml");
+    QTranslator translator;
 
+    QLocale locale = QLocale::system();
+    if (locale.language() == QLocale::Finnish) {
+	    translator.load("/opt/viito/viito_fi");
+	    app.installTranslator(&translator);
+    }
+
+    VMainWindow win("/opt/viito/data/images.xml");
     win.setWindowTitle(QLatin1String("Viito"));
     win.show();
     return app.exec();
