@@ -27,6 +27,7 @@ class QLabel;
 class QPixmap;
 class QEvent;
 class QKeyEvent;
+class QMouseEvent;
 class QGestureEvent;
 class QSwipeGesture;
 
@@ -37,8 +38,7 @@ class VImageWidget : public QWidget
 public:
     VImageWidget(QWidget *parent=0);
 
-    void setAuthor(const QString &author);
-    void setPixmap(const QPixmap &pixmap);
+    void setImage(const QString &path, const QString &author);
 
 protected:
     bool event(QEvent *);
@@ -51,12 +51,15 @@ private slots:
     void orientationChanged();
 
 private:
+    bool isLandscape();
     bool keyboardEvent(QKeyEvent *event);
+    bool screentapEvent(QMouseEvent *event);
     bool gestureEvent(QGestureEvent *event);
     bool handleSwipe(QSwipeGesture *swipe);
 
     QLabel *mAuthor;
     QLabel *mImage;
+    QPixmap mPixmap;
 };
 
 #endif // VIMAGEWIDGET_H
