@@ -22,7 +22,13 @@
 
 #include <QWidget>
 
-class QDomDocument;
+class QStandardItemModel;
+class QModelIndex;
+class QString;
+class QListView;
+class QLineEdit;
+class VImageWidget;
+class QSortFilterProxyModel;
 
 class VSearchWidget : public QWidget
 {
@@ -30,20 +36,25 @@ class VSearchWidget : public QWidget
 
 public:
     VSearchWidget(QWidget *parent=0);
-    setModel(QStandardItemModel *model);
 
-signals:
-    void imageSelected();
+    void setModel(QStandardItemModel *model);
 
 public slots:
-    void setLandscape(bool enabled);
-    void setSearch(bool enabled);
+    void show();
 
 private slots:
-    void 
-    Q
-    QLabel *mAuthor;
-    QLabel *mImage;
+    void imageClicked(const QModelIndex &index);
+    void searchEdited(const QString &text);
+    void nextImage();
+    void previousImage();
+
+private:
+    void setImage(const QModelIndex &index, int offset=0);
+
+    QListView *mView;
+    QLineEdit *mEdit;
+    VImageWidget *mImageWidget;
+    QSortFilterProxyModel *mModel;
 };
 
-#endif // VIMAGEWIDGET_H
+#endif // VSEARCHWIDGET_H
